==> ejc-lz-impl-3.0.0-20220831.061514-163-sources.jar: com/ejianc/business/base/controller/MaterialVarietiesController.java <==
package com.ejianc.business.base.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.base.bean.MaterialEntity;
import com.ejianc.business.base.bean.MaterialSpecEntity;
import com.ejianc.business.base.service.IMaterialService;
import com.ejianc.business.base.vo.MaterialVO;
import com.ejianc.business.base.vo.RequestVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.base.bean.MaterialVarietiesEntity;
import com.ejianc.business.base.service.IMaterialVarietiesService;
import com.ejianc.business.base.vo.MaterialVarietiesVO;

/**
 * 材料品种
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("materialVarieties")
public class MaterialVarietiesController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "material-varieties";//此处需要根据实际修改

    @Autowired
    private IMaterialVarietiesService service;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IMaterialService materialService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialVarietiesVO> saveOrUpdate(@RequestBody MaterialVarietiesVO saveOrUpdateVO) {
    	MaterialVarietiesEntity entity = BeanMapper.map(saveOrUpdateVO, MaterialVarietiesEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        QueryWrapper query=new QueryWrapper();
        query.eq("name",entity.getName());
        List<MaterialVarietiesEntity> list = service.list(query);
        if (list.size()>0){
            for (int i = 0; i < list.size(); i++) {
                MaterialVarietiesEntity Entity = list.get(i);
                if (!String.valueOf(Entity.getId()).equals(String.valueOf(entity.getId()))){
//                    System.out.println(saveId == editId);
                    throw new BusinessException("原材料品种名称已存在，请修改原材料品种名称后保存");
                }
            }
        }
    	service.saveOrUpdate(entity, false);
    	MaterialVarietiesVO vo = BeanMapper.map(entity, MaterialVarietiesVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialVarietiesVO> queryDetail(Long id) {
    	MaterialVarietiesEntity entity = service.selectById(id);
    	MaterialVarietiesVO vo = BeanMapper.map(entity, MaterialVarietiesVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MaterialVarietiesVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MaterialVarietiesVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                 /*CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MaterialVarietiesVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MaterialVarietiesVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("name");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

//        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
//        UserContext userContextCache =sessionManager.getUserContext();
//        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
//        String authOrgIds = userContextCache.getAuthOrgIds();
//        List<OrgVO> orgVOList = null;
//        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
//            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
//        }else {//pc端查询
//            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
//        }
//        //普通组织 id
//        List<Long> commonOrgIds = new ArrayList<>();
//        //项目部 id
//        List<Long> departmentIds = new ArrayList<>();
//        orgVOList.stream().forEach(org -> {
//            if(5 == org.getOrgType()) {
//                //项目部
//                departmentIds.add(org.getId());
//            } else {
//                //普通组织
//                commonOrgIds.add(org.getId());
//            }
//        });
//        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
//            /** 要求主表有orgId字段，保存单据所属组织 */
//            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
//        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
//            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
//            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
//        }
//        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<MaterialVarietiesEntity> page = service.queryPage(param,false);
        IPage<MaterialVarietiesVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialVarietiesVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MaterialVarietiesEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("MaterialVarieties-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refMaterialVarietiesData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MaterialVarietiesVO>> refMaterialVarietiesData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("name");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            String categoryId = _con.getString("categoryId");
            String asphaltId = _con.getString("asphaltId");
            String stoneId = _con.getString("stoneId");
            if (categoryId!=null) {
                param.getParams().put("category_id", new Parameter(QueryParam.EQ, categoryId));
            }
            if (asphaltId!=null) {
                param.getParams().put("category_id", new Parameter(QueryParam.EQ, asphaltId));
            }
            if (stoneId!=null){
                param.getParams().put("category_id", new Parameter(QueryParam.EQ, stoneId));
            }
        }

        IPage<MaterialVarietiesEntity> page = service.queryPage(param,false);
        IPage<MaterialVarietiesVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<MaterialVarietiesVO> materialVarietiesVO = BeanMapper.mapList(page.getRecords(), MaterialVarietiesVO.class);
        for(MaterialVarietiesVO materialVarieties : materialVarietiesVO){
            QueryWrapper<MaterialEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("varieties_id",materialVarieties.getId());
            List<MaterialEntity> list = materialService.list(queryWrapper);
            if(list.size() > 0){
                materialVarieties.setMaterialid(list.get(0).getId());
                materialVarieties.setMaterialcode(list.get(0).getBillCode());
                materialVarieties.setMaterialname(list.get(0).getName());
            }
        }
        pageData.setRecords(materialVarietiesVO);
        return CommonResponse.success("查询参照数据成功！",pageData);
     }

}

==> ejc-lz-impl-3.0.0-20220915.084847-172-sources.jar: com/ejianc/business/base/controller/MaterialVarietiesController.java <==
package com.ejianc.business.base.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.base.bean.MaterialEntity;
import com.ejianc.business.base.bean.MaterialSpecEntity;
import com.ejianc.business.base.service.IMaterialService;
import com.ejianc.business.base.vo.MaterialVO;
import com.ejianc.business.base.vo.RequestVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.base.bean.MaterialVarietiesEntity;
import com.ejianc.business.base.service.IMaterialVarietiesService;
import com.ejianc.business.base.vo.MaterialVarietiesVO;

/**
 * 材料品种
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("materialVarieties")
public class MaterialVarietiesController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "material-varieties";//此处需要根据实际修改

    @Autowired
    private IMaterialVarietiesService service;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IMaterialService materialService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialVarietiesVO> saveOrUpdate(@RequestBody MaterialVarietiesVO saveOrUpdateVO) {
    	MaterialVarietiesEntity entity = BeanMapper.map(saveOrUpdateVO, MaterialVarietiesEntity.class);

        QueryWrapper query=new QueryWrapper();
        query.eq("name",entity.getName());
        if(entity.getId() != null)
            query.ne("id",entity.getId());
        int count = service.count(query);
        if (count > 0)
            throw new BusinessException("原材料品种名称已存在，请修改原材料品种名称后保存");

    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }

    	service.saveOrUpdate(entity, false);
    	MaterialVarietiesVO vo = BeanMapper.map(entity, MaterialVarietiesVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialVarietiesVO> queryDetail(Long id) {
    	MaterialVarietiesEntity entity = service.selectById(id);
    	MaterialVarietiesVO vo = BeanMapper.map(entity, MaterialVarietiesVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MaterialVarietiesVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MaterialVarietiesVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                 /*CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MaterialVarietiesVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MaterialVarietiesVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("name");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

//        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
//        UserContext userContextCache =sessionManager.getUserContext();
//        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
//        String authOrgIds = userContextCache.getAuthOrgIds();
//        List<OrgVO> orgVOList = null;
//        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
//            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
//        }else {//pc端查询
//            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
//        }
//        //普通组织 id
//        List<Long> commonOrgIds = new ArrayList<>();
//        //项目部 id
//        List<Long> departmentIds = new ArrayList<>();
//        orgVOList.stream().forEach(org -> {
//            if(5 == org.getOrgType()) {
//                //项目部
//                departmentIds.add(org.getId());
//            } else {
//                //普通组织
//                commonOrgIds.add(org.getId());
//            }
//        });
//        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
//            /** 要求主表有orgId字段，保存单据所属组织 */
//            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
//        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
//            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
//            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
//        }
//        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<MaterialVarietiesEntity> page = service.queryPage(param,false);
        IPage<MaterialVarietiesVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialVarietiesVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MaterialVarietiesEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("MaterialVarieties-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refMaterialVarietiesData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MaterialVarietiesVO>> refMaterialVarietiesData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("name");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            String categoryId = _con.getString("categoryId");
            String asphaltId = _con.getString("asphaltId");
            String stoneId = _con.getString("stoneId");
            if (categoryId!=null) {
                param.getParams().put("category_id", new Parameter(QueryParam.EQ, categoryId));
            }
            if (asphaltId!=null) {
                param.getParams().put("category_id", new Parameter(QueryParam.EQ, asphaltId));
            }
            if (stoneId!=null){
                param.getParams().put("category_id", new Parameter(QueryParam.EQ, stoneId));
            }
        }

        IPage<MaterialVarietiesEntity> page = service.queryPage(param,false);
        IPage<MaterialVarietiesVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<MaterialVarietiesVO> materialVarietiesVO = BeanMapper.mapList(page.getRecords(), MaterialVarietiesVO.class);
        for(MaterialVarietiesVO materialVarieties : materialVarietiesVO){
            QueryWrapper<MaterialEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("varieties_id",materialVarieties.getId());
            List<MaterialEntity> list = materialService.list(queryWrapper);
            if(list.size() > 0){
                materialVarieties.setMaterialid(list.get(0).getId());
                materialVarieties.setMaterialcode(list.get(0).getBillCode());
                materialVarieties.setMaterialname(list.get(0).getName());
            }
        }
        pageData.setRecords(materialVarietiesVO);
        return CommonResponse.success("查询参照数据成功！",pageData);
     }

}
